# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 3.1.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InlineResponse2004(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'user_name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'active': 'bool',
        'groups': 'AssociatedGroupSchema'
    }

    attribute_map = {
        'user_id': 'userId',
        'user_name': 'userName',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'active': 'active',
        'groups': 'groups'
    }

    def __init__(self, user_id=None, user_name=None, first_name=None, last_name=None, email=None, active=None, groups=None):  # noqa: E501
        """InlineResponse2004 - a model defined in Swagger"""  # noqa: E501

        self._user_id = None
        self._user_name = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._active = None
        self._groups = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if active is not None:
            self.active = active
        if groups is not None:
            self.groups = groups

    @property
    def user_id(self):
        """Gets the user_id of this InlineResponse2004.  # noqa: E501

        ID generated by system  # noqa: E501

        :return: The user_id of this InlineResponse2004.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this InlineResponse2004.

        ID generated by system  # noqa: E501

        :param user_id: The user_id of this InlineResponse2004.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this InlineResponse2004.  # noqa: E501

        Name of the user  # noqa: E501

        :return: The user_name of this InlineResponse2004.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this InlineResponse2004.

        Name of the user  # noqa: E501

        :param user_name: The user_name of this InlineResponse2004.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def first_name(self):
        """Gets the first_name of this InlineResponse2004.  # noqa: E501

        First name of the user  # noqa: E501

        :return: The first_name of this InlineResponse2004.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this InlineResponse2004.

        First name of the user  # noqa: E501

        :param first_name: The first_name of this InlineResponse2004.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this InlineResponse2004.  # noqa: E501

        Last name of the user  # noqa: E501

        :return: The last_name of this InlineResponse2004.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this InlineResponse2004.

        Last name of the user  # noqa: E501

        :param last_name: The last_name of this InlineResponse2004.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this InlineResponse2004.  # noqa: E501

        Email of the user  # noqa: E501

        :return: The email of this InlineResponse2004.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this InlineResponse2004.

        Email of the user  # noqa: E501

        :param email: The email of this InlineResponse2004.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def active(self):
        """Gets the active of this InlineResponse2004.  # noqa: E501

        Status of the user  # noqa: E501

        :return: The active of this InlineResponse2004.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this InlineResponse2004.

        Status of the user  # noqa: E501

        :param active: The active of this InlineResponse2004.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def groups(self):
        """Gets the groups of this InlineResponse2004.  # noqa: E501


        :return: The groups of this InlineResponse2004.  # noqa: E501
        :rtype: AssociatedGroupSchema
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this InlineResponse2004.


        :param groups: The groups of this InlineResponse2004.  # noqa: E501
        :type: AssociatedGroupSchema
        """

        self._groups = groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2004, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2004):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
