# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 3.1.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DevicegroupSchemaSnmpV3UsmPrivacy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'passphrase': 'str',
        'protocol': 'str'
    }

    attribute_map = {
        'passphrase': 'passphrase',
        'protocol': 'protocol'
    }

    def __init__(self, passphrase=None, protocol=None):  # noqa: E501
        """DevicegroupSchemaSnmpV3UsmPrivacy - a model defined in Swagger"""  # noqa: E501

        self._passphrase = None
        self._protocol = None
        self.discriminator = None

        self.passphrase = passphrase
        self.protocol = protocol

    @property
    def passphrase(self):
        """Gets the passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501

        Passphrase for SNMPv3 privacy  # noqa: E501

        :return: The passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :rtype: str
        """
        return self._passphrase

    @passphrase.setter
    def passphrase(self, passphrase):
        """Sets the passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.

        Passphrase for SNMPv3 privacy  # noqa: E501

        :param passphrase: The passphrase of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :type: str
        """
        if passphrase is None:
            raise ValueError("Invalid value for `passphrase`, must not be `None`")  # noqa: E501

        self._passphrase = passphrase

    @property
    def protocol(self):
        """Gets the protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501

        SNMPv3 privacy protocol  # noqa: E501

        :return: The protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.

        SNMPv3 privacy protocol  # noqa: E501

        :param protocol: The protocol of this DevicegroupSchemaSnmpV3UsmPrivacy.  # noqa: E501
        :type: str
        """
        if protocol is None:
            raise ValueError("Invalid value for `protocol`, must not be `None`")  # noqa: E501
        allowed_values = ["DES", "AES", "AES192", "AES256", "AES192C", "AES256C"]  # noqa: E501
        if protocol not in allowed_values:
            raise ValueError(
                "Invalid value for `protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol, allowed_values)
            )

        self._protocol = protocol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicegroupSchemaSnmpV3UsmPrivacy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicegroupSchemaSnmpV3UsmPrivacy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
