# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaggingprofileSchemaWhen(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'does_not_match_with': 'list[TaggingprofileSchemaWhenDoesnotmatchwith]',
        'equal_to': 'list[TaggingprofileSchemaWhenEqualto]',
        'eval': 'list[TopicSchemaWhereEval]',
        'exists': 'list[TaggingprofileSchemaWhenExists]',
        'greater_than': 'list[TaggingprofileSchemaWhenEqualto]',
        'greater_than_or_equal_to': 'list[TaggingprofileSchemaWhenEqualto]',
        'less_than': 'list[TaggingprofileSchemaWhenEqualto]',
        'less_than_or_equal_to': 'list[TaggingprofileSchemaWhenEqualto]',
        'matches_with': 'list[TaggingprofileSchemaWhenDoesnotmatchwith]',
        'matches_with_scheduler': 'TaggingprofileSchemaWhenMatcheswithscheduler',
        'does_not_match_with_scheduler': 'TaggingprofileSchemaWhenMatcheswithscheduler',
        'not_equal_to': 'list[TaggingprofileSchemaWhenEqualto]'
    }

    attribute_map = {
        'does_not_match_with': 'does-not-match-with',
        'equal_to': 'equal-to',
        'eval': 'eval',
        'exists': 'exists',
        'greater_than': 'greater-than',
        'greater_than_or_equal_to': 'greater-than-or-equal-to',
        'less_than': 'less-than',
        'less_than_or_equal_to': 'less-than-or-equal-to',
        'matches_with': 'matches-with',
        'matches_with_scheduler': 'matches-with-scheduler',
        'does_not_match_with_scheduler': 'does-not-match-with-scheduler',
        'not_equal_to': 'not-equal-to'
    }

    def __init__(self, does_not_match_with=None, equal_to=None, eval=None, exists=None, greater_than=None, greater_than_or_equal_to=None, less_than=None, less_than_or_equal_to=None, matches_with=None, matches_with_scheduler=None, does_not_match_with_scheduler=None, not_equal_to=None):  # noqa: E501
        """TaggingprofileSchemaWhen - a model defined in Swagger"""  # noqa: E501

        self._does_not_match_with = None
        self._equal_to = None
        self._eval = None
        self._exists = None
        self._greater_than = None
        self._greater_than_or_equal_to = None
        self._less_than = None
        self._less_than_or_equal_to = None
        self._matches_with = None
        self._matches_with_scheduler = None
        self._does_not_match_with_scheduler = None
        self._not_equal_to = None
        self.discriminator = None

        if does_not_match_with is not None:
            self.does_not_match_with = does_not_match_with
        if equal_to is not None:
            self.equal_to = equal_to
        if eval is not None:
            self.eval = eval
        if exists is not None:
            self.exists = exists
        if greater_than is not None:
            self.greater_than = greater_than
        if greater_than_or_equal_to is not None:
            self.greater_than_or_equal_to = greater_than_or_equal_to
        if less_than is not None:
            self.less_than = less_than
        if less_than_or_equal_to is not None:
            self.less_than_or_equal_to = less_than_or_equal_to
        if matches_with is not None:
            self.matches_with = matches_with
        if matches_with_scheduler is not None:
            self.matches_with_scheduler = matches_with_scheduler
        if does_not_match_with_scheduler is not None:
            self.does_not_match_with_scheduler = does_not_match_with_scheduler
        if not_equal_to is not None:
            self.not_equal_to = not_equal_to

    @property
    def does_not_match_with(self):
        """Gets the does_not_match_with of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The does_not_match_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """
        return self._does_not_match_with

    @does_not_match_with.setter
    def does_not_match_with(self, does_not_match_with):
        """Sets the does_not_match_with of this TaggingprofileSchemaWhen.


        :param does_not_match_with: The does_not_match_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """

        self._does_not_match_with = does_not_match_with

    @property
    def equal_to(self):
        """Gets the equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._equal_to

    @equal_to.setter
    def equal_to(self, equal_to):
        """Sets the equal_to of this TaggingprofileSchemaWhen.


        :param equal_to: The equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._equal_to = equal_to

    @property
    def eval(self):
        """Gets the eval of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The eval of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TopicSchemaWhereEval]
        """
        return self._eval

    @eval.setter
    def eval(self, eval):
        """Sets the eval of this TaggingprofileSchemaWhen.


        :param eval: The eval of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TopicSchemaWhereEval]
        """

        self._eval = eval

    @property
    def exists(self):
        """Gets the exists of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The exists of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenExists]
        """
        return self._exists

    @exists.setter
    def exists(self, exists):
        """Sets the exists of this TaggingprofileSchemaWhen.


        :param exists: The exists of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenExists]
        """

        self._exists = exists

    @property
    def greater_than(self):
        """Gets the greater_than of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The greater_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._greater_than

    @greater_than.setter
    def greater_than(self, greater_than):
        """Sets the greater_than of this TaggingprofileSchemaWhen.


        :param greater_than: The greater_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._greater_than = greater_than

    @property
    def greater_than_or_equal_to(self):
        """Gets the greater_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The greater_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._greater_than_or_equal_to

    @greater_than_or_equal_to.setter
    def greater_than_or_equal_to(self, greater_than_or_equal_to):
        """Sets the greater_than_or_equal_to of this TaggingprofileSchemaWhen.


        :param greater_than_or_equal_to: The greater_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._greater_than_or_equal_to = greater_than_or_equal_to

    @property
    def less_than(self):
        """Gets the less_than of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The less_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._less_than

    @less_than.setter
    def less_than(self, less_than):
        """Sets the less_than of this TaggingprofileSchemaWhen.


        :param less_than: The less_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._less_than = less_than

    @property
    def less_than_or_equal_to(self):
        """Gets the less_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The less_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._less_than_or_equal_to

    @less_than_or_equal_to.setter
    def less_than_or_equal_to(self, less_than_or_equal_to):
        """Sets the less_than_or_equal_to of this TaggingprofileSchemaWhen.


        :param less_than_or_equal_to: The less_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._less_than_or_equal_to = less_than_or_equal_to

    @property
    def matches_with(self):
        """Gets the matches_with of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The matches_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """
        return self._matches_with

    @matches_with.setter
    def matches_with(self, matches_with):
        """Sets the matches_with of this TaggingprofileSchemaWhen.


        :param matches_with: The matches_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """

        self._matches_with = matches_with

    @property
    def matches_with_scheduler(self):
        """Gets the matches_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The matches_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: TaggingprofileSchemaWhenMatcheswithscheduler
        """
        return self._matches_with_scheduler

    @matches_with_scheduler.setter
    def matches_with_scheduler(self, matches_with_scheduler):
        """Sets the matches_with_scheduler of this TaggingprofileSchemaWhen.


        :param matches_with_scheduler: The matches_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: TaggingprofileSchemaWhenMatcheswithscheduler
        """

        self._matches_with_scheduler = matches_with_scheduler

    @property
    def does_not_match_with_scheduler(self):
        """Gets the does_not_match_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The does_not_match_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: TaggingprofileSchemaWhenMatcheswithscheduler
        """
        return self._does_not_match_with_scheduler

    @does_not_match_with_scheduler.setter
    def does_not_match_with_scheduler(self, does_not_match_with_scheduler):
        """Sets the does_not_match_with_scheduler of this TaggingprofileSchemaWhen.


        :param does_not_match_with_scheduler: The does_not_match_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: TaggingprofileSchemaWhenMatcheswithscheduler
        """

        self._does_not_match_with_scheduler = does_not_match_with_scheduler

    @property
    def not_equal_to(self):
        """Gets the not_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The not_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._not_equal_to

    @not_equal_to.setter
    def not_equal_to(self, not_equal_to):
        """Sets the not_equal_to of this TaggingprofileSchemaWhen.


        :param not_equal_to: The not_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._not_equal_to = not_equal_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaggingprofileSchemaWhen, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaggingprofileSchemaWhen):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
