# coding: utf-8

# flake8: noqa
"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from jnpr.healthbot.swagger.models.affected_groups import AffectedGroups
from jnpr.healthbot.swagger.models.apply_macro_schema import ApplyMacroSchema
from jnpr.healthbot.swagger.models.applymacro_schema_data import ApplymacroSchemaData
from jnpr.healthbot.swagger.models.associated_group_schema import AssociatedGroupSchema
from jnpr.healthbot.swagger.models.associated_role_schema import AssociatedRoleSchema
from jnpr.healthbot.swagger.models.associated_role_schema_inner import AssociatedRoleSchemaInner
from jnpr.healthbot.swagger.models.associated_user_schema import AssociatedUserSchema
from jnpr.healthbot.swagger.models.associated_user_schema_inner import AssociatedUserSchemaInner
from jnpr.healthbot.swagger.models.ca_profile_schema import CaProfileSchema
from jnpr.healthbot.swagger.models.command_rpc import CommandRpc
from jnpr.healthbot.swagger.models.commit_job import CommitJob
from jnpr.healthbot.swagger.models.counter_record_schema import CounterRecordSchema
from jnpr.healthbot.swagger.models.credenetial import Credenetial
from jnpr.healthbot.swagger.models.credential import Credential
from jnpr.healthbot.swagger.models.custom_plugin_schema import CustomPluginSchema
from jnpr.healthbot.swagger.models.custom_plugins_schema import CustomPluginsSchema
from jnpr.healthbot.swagger.models.customplugin_schema_parameters import CustompluginSchemaParameters
from jnpr.healthbot.swagger.models.customplugin_schema_securityparameters import CustompluginSchemaSecurityparameters
from jnpr.healthbot.swagger.models.customplugin_schema_securityparameters_tls import CustompluginSchemaSecurityparametersTls
from jnpr.healthbot.swagger.models.customplugin_schema_securityparameters_userauthentication import CustompluginSchemaSecurityparametersUserauthentication
from jnpr.healthbot.swagger.models.datastore_schema import DatastoreSchema
from jnpr.healthbot.swagger.models.debug_arguments_schema import DebugArgumentsSchema
from jnpr.healthbot.swagger.models.debug_job_response_schema import DebugJobResponseSchema
from jnpr.healthbot.swagger.models.deployment_schema import DeploymentSchema
from jnpr.healthbot.swagger.models.deployment_schema_deployment import DeploymentSchemaDeployment
from jnpr.healthbot.swagger.models.deployment_schema_deployment_kubernetes import DeploymentSchemaDeploymentKubernetes
from jnpr.healthbot.swagger.models.deployment_schema_deployment_kubernetes_loadbalancer import DeploymentSchemaDeploymentKubernetesLoadbalancer
from jnpr.healthbot.swagger.models.deployment_schema_deployment_kubernetes_loadbalancer_snmpproxy import DeploymentSchemaDeploymentKubernetesLoadbalancerSnmpproxy
from jnpr.healthbot.swagger.models.destination_schema import DestinationSchema
from jnpr.healthbot.swagger.models.destination_schema_disk import DestinationSchemaDisk
from jnpr.healthbot.swagger.models.destination_schema_email import DestinationSchemaEmail
from jnpr.healthbot.swagger.models.destinations_schema import DestinationsSchema
from jnpr.healthbot.swagger.models.device_details_schema import DeviceDetailsSchema
from jnpr.healthbot.swagger.models.device_field_capture_schema import DeviceFieldCaptureSchema
from jnpr.healthbot.swagger.models.device_group_field_capture_schema import DeviceGroupFieldCaptureSchema
from jnpr.healthbot.swagger.models.device_group_health_tree import DeviceGroupHealthTree
from jnpr.healthbot.swagger.models.device_group_schema import DeviceGroupSchema
from jnpr.healthbot.swagger.models.device_groups_schema import DeviceGroupsSchema
from jnpr.healthbot.swagger.models.device_health_schema import DeviceHealthSchema
from jnpr.healthbot.swagger.models.device_health_tree import DeviceHealthTree
from jnpr.healthbot.swagger.models.device_schema import DeviceSchema
from jnpr.healthbot.swagger.models.device_schema_flow import DeviceSchemaFlow
from jnpr.healthbot.swagger.models.device_schema_i_agent import DeviceSchemaIAgent
from jnpr.healthbot.swagger.models.device_schema_openconfig import DeviceSchemaOpenconfig
from jnpr.healthbot.swagger.models.device_schema_outboundssh import DeviceSchemaOutboundssh
from jnpr.healthbot.swagger.models.device_schema_snmp import DeviceSchemaSnmp
from jnpr.healthbot.swagger.models.device_schema_snmp_v2 import DeviceSchemaSnmpV2
from jnpr.healthbot.swagger.models.device_schema_snmp_v2_sourceid import DeviceSchemaSnmpV2Sourceid
from jnpr.healthbot.swagger.models.device_schema_snmp_v3 import DeviceSchemaSnmpV3
from jnpr.healthbot.swagger.models.device_schema_snmp_v3_sourceid import DeviceSchemaSnmpV3Sourceid
from jnpr.healthbot.swagger.models.device_schema_snmp_v3_usm import DeviceSchemaSnmpV3Usm
from jnpr.healthbot.swagger.models.device_schema_syslog import DeviceSchemaSyslog
from jnpr.healthbot.swagger.models.device_schema_variable import DeviceSchemaVariable
from jnpr.healthbot.swagger.models.device_schema_vendor import DeviceSchemaVendor
from jnpr.healthbot.swagger.models.device_schema_vendor_arista import DeviceSchemaVendorArista
from jnpr.healthbot.swagger.models.device_schema_vendor_cisco import DeviceSchemaVendorCisco
from jnpr.healthbot.swagger.models.device_schema_vendor_juniper import DeviceSchemaVendorJuniper
from jnpr.healthbot.swagger.models.device_schema_vendor_linux import DeviceSchemaVendorLinux
from jnpr.healthbot.swagger.models.device_schema_vendor_othervendor import DeviceSchemaVendorOthervendor
from jnpr.healthbot.swagger.models.device_schema_vendor_paloalto import DeviceSchemaVendorPaloalto
from jnpr.healthbot.swagger.models.devicegroup_schema_actionscheduler import DevicegroupSchemaActionscheduler
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication import DevicegroupSchemaAuthentication
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication_password import DevicegroupSchemaAuthenticationPassword
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication_ssh import DevicegroupSchemaAuthenticationSsh
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication_ssl import DevicegroupSchemaAuthenticationSsl
from jnpr.healthbot.swagger.models.devicegroup_schema_fielddata import DevicegroupSchemaFielddata
from jnpr.healthbot.swagger.models.devicegroup_schema_fielddata_rollup import DevicegroupSchemaFielddataRollup
from jnpr.healthbot.swagger.models.devicegroup_schema_flow import DevicegroupSchemaFlow
from jnpr.healthbot.swagger.models.devicegroup_schema_flow_netflow import DevicegroupSchemaFlowNetflow
from jnpr.healthbot.swagger.models.devicegroup_schema_flow_sflow import DevicegroupSchemaFlowSflow
from jnpr.healthbot.swagger.models.devicegroup_schema_logging import DevicegroupSchemaLogging
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_byoi import DevicegroupSchemaLoggingByoi
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_byoi_service import DevicegroupSchemaLoggingByoiService
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_flow import DevicegroupSchemaLoggingFlow
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_i_agent import DevicegroupSchemaLoggingIAgent
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_m_lmodelbuilder import DevicegroupSchemaLoggingMLmodelbuilder
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_nativegpb import DevicegroupSchemaLoggingNativegpb
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_nonsensorrules import DevicegroupSchemaLoggingNonsensorrules
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_openconfig import DevicegroupSchemaLoggingOpenconfig
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_reportsgeneration import DevicegroupSchemaLoggingReportsgeneration
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_resourcediscovery import DevicegroupSchemaLoggingResourcediscovery
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_servermonitoring import DevicegroupSchemaLoggingServermonitoring
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_sflow import DevicegroupSchemaLoggingSflow
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_snmp import DevicegroupSchemaLoggingSnmp
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_snmpnotification import DevicegroupSchemaLoggingSnmpnotification
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_syslog import DevicegroupSchemaLoggingSyslog
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_triggerevaluation import DevicegroupSchemaLoggingTriggerevaluation
from jnpr.healthbot.swagger.models.devicegroup_schema_nativegpb import DevicegroupSchemaNativegpb
from jnpr.healthbot.swagger.models.devicegroup_schema_notification import DevicegroupSchemaNotification
from jnpr.healthbot.swagger.models.devicegroup_schema_openconfig import DevicegroupSchemaOpenconfig
from jnpr.healthbot.swagger.models.devicegroup_schema_openconfig_gnmi import DevicegroupSchemaOpenconfigGnmi
from jnpr.healthbot.swagger.models.devicegroup_schema_outboundssh import DevicegroupSchemaOutboundssh
from jnpr.healthbot.swagger.models.devicegroup_schema_publish import DevicegroupSchemaPublish
from jnpr.healthbot.swagger.models.devicegroup_schema_rawdata import DevicegroupSchemaRawdata
from jnpr.healthbot.swagger.models.devicegroup_schema_rawdata_summarize import DevicegroupSchemaRawdataSummarize
from jnpr.healthbot.swagger.models.devicegroup_schema_rootcauseanalysis import DevicegroupSchemaRootcauseanalysis
from jnpr.healthbot.swagger.models.devicegroup_schema_scheduler import DevicegroupSchemaScheduler
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp import DevicegroupSchemaSnmp
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v2 import DevicegroupSchemaSnmpV2
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v3 import DevicegroupSchemaSnmpV3
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v3_usm import DevicegroupSchemaSnmpV3Usm
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v3_usm_snmpproxyforwarder import DevicegroupSchemaSnmpV3UsmSnmpproxyforwarder
from jnpr.healthbot.swagger.models.devicegroup_schema_syslog import DevicegroupSchemaSyslog
from jnpr.healthbot.swagger.models.devicegroup_schema_variable import DevicegroupSchemaVariable
from jnpr.healthbot.swagger.models.devicegroup_schema_variablevalue import DevicegroupSchemaVariablevalue
from jnpr.healthbot.swagger.models.devices_schema import DevicesSchema
from jnpr.healthbot.swagger.models.dynamic_tagging_schema_object import DynamicTaggingSchemaObject
from jnpr.healthbot.swagger.models.dynamic_taggings_schema_object import DynamicTaggingsSchemaObject
from jnpr.healthbot.swagger.models.edge_schema import EdgeSchema
from jnpr.healthbot.swagger.models.error import Error
from jnpr.healthbot.swagger.models.event import Event
from jnpr.healthbot.swagger.models.field_capture_schema import FieldCaptureSchema
from jnpr.healthbot.swagger.models.field_field_capture_schema import FieldFieldCaptureSchema
from jnpr.healthbot.swagger.models.flow_record_schema import FlowRecordSchema
from jnpr.healthbot.swagger.models.flow_schema import FlowSchema
from jnpr.healthbot.swagger.models.flow_schema_flow import FlowSchemaFlow
from jnpr.healthbot.swagger.models.flow_schema_flow_recognitionpattern import FlowSchemaFlowRecognitionpattern
from jnpr.healthbot.swagger.models.flow_schema_flow_template import FlowSchemaFlowTemplate
from jnpr.healthbot.swagger.models.frequency_profile_schema import FrequencyProfileSchema
from jnpr.healthbot.swagger.models.frequencyprofile_schema_nonsensor import FrequencyprofileSchemaNonsensor
from jnpr.healthbot.swagger.models.frequencyprofile_schema_sensor import FrequencyprofileSchemaSensor
from jnpr.healthbot.swagger.models.group_health_schema import GroupHealthSchema
from jnpr.healthbot.swagger.models.hb_graphs import HbGraphs
from jnpr.healthbot.swagger.models.hb_graphs_query import HbGraphsQuery
from jnpr.healthbot.swagger.models.hb_graphs_query_where import HbGraphsQueryWhere
from jnpr.healthbot.swagger.models.hb_graphs_query_where_where_clause import HbGraphsQueryWhereWhereClause
from jnpr.healthbot.swagger.models.header_pattern_schema import HeaderPatternSchema
from jnpr.healthbot.swagger.models.headerpattern_schema_field import HeaderpatternSchemaField
from jnpr.healthbot.swagger.models.health_schema import HealthSchema
from jnpr.healthbot.swagger.models.ingest_mapping_schema import IngestMappingSchema
from jnpr.healthbot.swagger.models.ingest_mappings_schema import IngestMappingsSchema
from jnpr.healthbot.swagger.models.ingest_settings_schema import IngestSettingsSchema
from jnpr.healthbot.swagger.models.ingestmapping_schema_i_agent import IngestmappingSchemaIAgent
from jnpr.healthbot.swagger.models.ingestmapping_schema_i_agent_useplugin import IngestmappingSchemaIAgentUseplugin
from jnpr.healthbot.swagger.models.ingestmapping_schema_nativegpb import IngestmappingSchemaNativegpb
from jnpr.healthbot.swagger.models.ingestmapping_schema_netflow import IngestmappingSchemaNetflow
from jnpr.healthbot.swagger.models.ingestmapping_schema_openconfig import IngestmappingSchemaOpenconfig
from jnpr.healthbot.swagger.models.ingestmapping_schema_snmp import IngestmappingSchemaSnmp
from jnpr.healthbot.swagger.models.ingestmapping_schema_syslog import IngestmappingSchemaSyslog
from jnpr.healthbot.swagger.models.inline_response200 import InlineResponse200
from jnpr.healthbot.swagger.models.inline_response2001 import InlineResponse2001
from jnpr.healthbot.swagger.models.inline_response2002 import InlineResponse2002
from jnpr.healthbot.swagger.models.instance_schedule_state_schema import InstanceScheduleStateSchema
from jnpr.healthbot.swagger.models.instances_schedule_state_schema import InstancesScheduleStateSchema
from jnpr.healthbot.swagger.models.lhs_rhs_group import LhsRhsGroup
from jnpr.healthbot.swagger.models.license_feature_schema import LicenseFeatureSchema
from jnpr.healthbot.swagger.models.license_features_schema import LicenseFeaturesSchema
from jnpr.healthbot.swagger.models.license_key_schema import LicenseKeySchema
from jnpr.healthbot.swagger.models.license_keys_schema import LicenseKeysSchema
from jnpr.healthbot.swagger.models.license_raw_key_schema import LicenseRawKeySchema
from jnpr.healthbot.swagger.models.license_raw_keys_schema import LicenseRawKeysSchema
from jnpr.healthbot.swagger.models.licensekey_schema_features import LicensekeySchemaFeatures
from jnpr.healthbot.swagger.models.local_certificate_schema import LocalCertificateSchema
from jnpr.healthbot.swagger.models.native_gpb_schema import NativeGpbSchema
from jnpr.healthbot.swagger.models.nativegpb_schema_nativegpb import NativegpbSchemaNativegpb
from jnpr.healthbot.swagger.models.network_group_schema import NetworkGroupSchema
from jnpr.healthbot.swagger.models.network_groups_schema import NetworkGroupsSchema
from jnpr.healthbot.swagger.models.network_health_tree import NetworkHealthTree
from jnpr.healthbot.swagger.models.networkgroup_schema_logging import NetworkgroupSchemaLogging
from jnpr.healthbot.swagger.models.networkgroup_schema_notification import NetworkgroupSchemaNotification
from jnpr.healthbot.swagger.models.networkgroup_schema_publish import NetworkgroupSchemaPublish
from jnpr.healthbot.swagger.models.notification_schema import NotificationSchema
from jnpr.healthbot.swagger.models.notification_schema_amqppublish import NotificationSchemaAmqppublish
from jnpr.healthbot.swagger.models.notification_schema_amqppublish_sasl import NotificationSchemaAmqppublishSasl
from jnpr.healthbot.swagger.models.notification_schema_emails import NotificationSchemaEmails
from jnpr.healthbot.swagger.models.notification_schema_emails_filter import NotificationSchemaEmailsFilter
from jnpr.healthbot.swagger.models.notification_schema_httppost import NotificationSchemaHttppost
from jnpr.healthbot.swagger.models.notification_schema_httppost_basic import NotificationSchemaHttppostBasic
from jnpr.healthbot.swagger.models.notification_schema_kafkapublish import NotificationSchemaKafkapublish
from jnpr.healthbot.swagger.models.notification_schema_kafkapublish_sasl import NotificationSchemaKafkapublishSasl
from jnpr.healthbot.swagger.models.notification_schema_microsoftteams import NotificationSchemaMicrosoftteams
from jnpr.healthbot.swagger.models.notification_schema_slack import NotificationSchemaSlack
from jnpr.healthbot.swagger.models.notifications_schema import NotificationsSchema
from jnpr.healthbot.swagger.models.organization_schema import OrganizationSchema
from jnpr.healthbot.swagger.models.organizations_schema import OrganizationsSchema
from jnpr.healthbot.swagger.models.outbound_ssh_schema import OutboundSshSchema
from jnpr.healthbot.swagger.models.outboundssh_schema_outboundssh import OutboundsshSchemaOutboundssh
from jnpr.healthbot.swagger.models.panel_data_schema import PanelDataSchema
from jnpr.healthbot.swagger.models.panel_data_schema_add_group_by_tag import PanelDataSchemaAddGroupByTag
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition import PanelDataSchemaAddWhereCondition
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition_key_or_field import PanelDataSchemaAddWhereConditionKeyOrField
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition_key_or_field_value import PanelDataSchemaAddWhereConditionKeyOrFieldValue
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition_operator import PanelDataSchemaAddWhereConditionOperator
from jnpr.healthbot.swagger.models.panel_data_schema_change_where_key_field import PanelDataSchemaChangeWhereKeyField
from jnpr.healthbot.swagger.models.panel_data_schema_group_by_fill import PanelDataSchemaGroupByFill
from jnpr.healthbot.swagger.models.panel_data_schema_group_by_time import PanelDataSchemaGroupByTime
from jnpr.healthbot.swagger.models.panel_data_schema_selected_aggregation import PanelDataSchemaSelectedAggregation
from jnpr.healthbot.swagger.models.panel_data_schema_selected_device import PanelDataSchemaSelectedDevice
from jnpr.healthbot.swagger.models.panel_data_schema_selected_dropdown import PanelDataSchemaSelectedDropdown
from jnpr.healthbot.swagger.models.panel_data_schema_selected_field import PanelDataSchemaSelectedField
from jnpr.healthbot.swagger.models.panel_data_schema_selected_group import PanelDataSchemaSelectedGroup
from jnpr.healthbot.swagger.models.panel_data_schema_selected_logical_operator import PanelDataSchemaSelectedLogicalOperator
from jnpr.healthbot.swagger.models.panel_data_schema_selected_topic import PanelDataSchemaSelectedTopic
from jnpr.healthbot.swagger.models.panel_data_schema_selected_transformation import PanelDataSchemaSelectedTransformation
from jnpr.healthbot.swagger.models.panel_schema import PanelSchema
from jnpr.healthbot.swagger.models.panel_schema_panel_query import PanelSchemaPanelQuery
from jnpr.healthbot.swagger.models.panel_schema_panel_type import PanelSchemaPanelType
from jnpr.healthbot.swagger.models.panel_schema_time_range import PanelSchemaTimeRange
from jnpr.healthbot.swagger.models.panel_schema_unit_type import PanelSchemaUnitType
from jnpr.healthbot.swagger.models.pattern_schema import PatternSchema
from jnpr.healthbot.swagger.models.pattern_schema_constant import PatternSchemaConstant
from jnpr.healthbot.swagger.models.pattern_schema_field import PatternSchemaField
from jnpr.healthbot.swagger.models.pattern_set_schema import PatternSetSchema
from jnpr.healthbot.swagger.models.playbook_schema import PlaybookSchema
from jnpr.healthbot.swagger.models.playbooks_schema import PlaybooksSchema
from jnpr.healthbot.swagger.models.profile_schema import ProfileSchema
from jnpr.healthbot.swagger.models.profile_schema_datasummarization import ProfileSchemaDatasummarization
from jnpr.healthbot.swagger.models.profile_schema_datasummarization_path import ProfileSchemaDatasummarizationPath
from jnpr.healthbot.swagger.models.profile_schema_datasummarization_raw import ProfileSchemaDatasummarizationRaw
from jnpr.healthbot.swagger.models.profile_schema_rollupsummarization import ProfileSchemaRollupsummarization
from jnpr.healthbot.swagger.models.profile_schema_security import ProfileSchemaSecurity
from jnpr.healthbot.swagger.models.profiles_schema import ProfilesSchema
from jnpr.healthbot.swagger.models.profiles_schema_profile import ProfilesSchemaProfile
from jnpr.healthbot.swagger.models.protocol_schema import ProtocolSchema
from jnpr.healthbot.swagger.models.raw_data_summarizations_schema import RawDataSummarizationsSchema
from jnpr.healthbot.swagger.models.raw_schema import RawSchema
from jnpr.healthbot.swagger.models.raw_schema_datatype import RawSchemaDatatype
from jnpr.healthbot.swagger.models.raw_schema_path import RawSchemaPath
from jnpr.healthbot.swagger.models.refresh_token import RefreshToken
from jnpr.healthbot.swagger.models.report_generation_schema import ReportGenerationSchema
from jnpr.healthbot.swagger.models.report_schema import ReportSchema
from jnpr.healthbot.swagger.models.report_schema_canvaspanel import ReportSchemaCanvaspanel
from jnpr.healthbot.swagger.models.report_schema_graphcanvas import ReportSchemaGraphcanvas
from jnpr.healthbot.swagger.models.reports_schema import ReportsSchema
from jnpr.healthbot.swagger.models.resource_schema import ResourceSchema
from jnpr.healthbot.swagger.models.retention_policies_schema import RetentionPoliciesSchema
from jnpr.healthbot.swagger.models.retention_policy_schema import RetentionPolicySchema
from jnpr.healthbot.swagger.models.role_schema import RoleSchema
from jnpr.healthbot.swagger.models.role_schema_inner import RoleSchemaInner
from jnpr.healthbot.swagger.models.rollup_summarization_schema import RollupSummarizationSchema
from jnpr.healthbot.swagger.models.rollup_summarizations_schema import RollupSummarizationsSchema
from jnpr.healthbot.swagger.models.rollupsummarization_schema_database import RollupsummarizationSchemaDatabase
from jnpr.healthbot.swagger.models.rollupsummarization_schema_datarolluporder import RollupsummarizationSchemaDatarolluporder
from jnpr.healthbot.swagger.models.rollupsummarization_schema_field import RollupsummarizationSchemaField
from jnpr.healthbot.swagger.models.rollupsummarization_schema_field1 import RollupsummarizationSchemaField1
from jnpr.healthbot.swagger.models.rollupsummarization_schema_measurement import RollupsummarizationSchemaMeasurement
from jnpr.healthbot.swagger.models.rollupsummarization_schema_rule import RollupsummarizationSchemaRule
from jnpr.healthbot.swagger.models.rule_field_capture_schema import RuleFieldCaptureSchema
from jnpr.healthbot.swagger.models.rule_schema import RuleSchema
from jnpr.healthbot.swagger.models.rule_schema_argument import RuleSchemaArgument
from jnpr.healthbot.swagger.models.rule_schema_byoi import RuleSchemaByoi
from jnpr.healthbot.swagger.models.rule_schema_byoi_plugin import RuleSchemaByoiPlugin
from jnpr.healthbot.swagger.models.rule_schema_byoi_plugin_parameters import RuleSchemaByoiPluginParameters
from jnpr.healthbot.swagger.models.rule_schema_constant import RuleSchemaConstant
from jnpr.healthbot.swagger.models.rule_schema_dataifmissing import RuleSchemaDataifmissing
from jnpr.healthbot.swagger.models.rule_schema_field import RuleSchemaField
from jnpr.healthbot.swagger.models.rule_schema_flow import RuleSchemaFlow
from jnpr.healthbot.swagger.models.rule_schema_formula import RuleSchemaFormula
from jnpr.healthbot.swagger.models.rule_schema_formula1 import RuleSchemaFormula1
from jnpr.healthbot.swagger.models.rule_schema_formula1_and import RuleSchemaFormula1And
from jnpr.healthbot.swagger.models.rule_schema_formula1_or import RuleSchemaFormula1Or
from jnpr.healthbot.swagger.models.rule_schema_formula1_unique import RuleSchemaFormula1Unique
from jnpr.healthbot.swagger.models.rule_schema_formula1_unless import RuleSchemaFormula1Unless
from jnpr.healthbot.swagger.models.rule_schema_formula_anomalydetection import RuleSchemaFormulaAnomalydetection
from jnpr.healthbot.swagger.models.rule_schema_formula_concatenate import RuleSchemaFormulaConcatenate
from jnpr.healthbot.swagger.models.rule_schema_formula_count import RuleSchemaFormulaCount
from jnpr.healthbot.swagger.models.rule_schema_formula_dynamicthreshold import RuleSchemaFormulaDynamicthreshold
from jnpr.healthbot.swagger.models.rule_schema_formula_elapsedtime import RuleSchemaFormulaElapsedtime
from jnpr.healthbot.swagger.models.rule_schema_formula_eval import RuleSchemaFormulaEval
from jnpr.healthbot.swagger.models.rule_schema_formula_max import RuleSchemaFormulaMax
from jnpr.healthbot.swagger.models.rule_schema_formula_mean import RuleSchemaFormulaMean
from jnpr.healthbot.swagger.models.rule_schema_formula_microburst import RuleSchemaFormulaMicroburst
from jnpr.healthbot.swagger.models.rule_schema_formula_min import RuleSchemaFormulaMin
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection import RuleSchemaFormulaOutlierdetection
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm import RuleSchemaFormulaOutlierdetectionAlgorithm
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm_dbscan import RuleSchemaFormulaOutlierdetectionAlgorithmDbscan
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm_dbscan_sensitivity import RuleSchemaFormulaOutlierdetectionAlgorithmDbscanSensitivity
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm_kfold3sigma import RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma
from jnpr.healthbot.swagger.models.rule_schema_formula_predict import RuleSchemaFormulaPredict
from jnpr.healthbot.swagger.models.rule_schema_formula_rateofchange import RuleSchemaFormulaRateofchange
from jnpr.healthbot.swagger.models.rule_schema_formula_stddev import RuleSchemaFormulaStddev
from jnpr.healthbot.swagger.models.rule_schema_formula_sum import RuleSchemaFormulaSum
from jnpr.healthbot.swagger.models.rule_schema_formula_userdefinedfunction import RuleSchemaFormulaUserdefinedfunction
from jnpr.healthbot.swagger.models.rule_schema_formula_userdefinedfunction_argument import RuleSchemaFormulaUserdefinedfunctionArgument
from jnpr.healthbot.swagger.models.rule_schema_formula_valuedifference import RuleSchemaFormulaValuedifference
from jnpr.healthbot.swagger.models.rule_schema_function import RuleSchemaFunction
from jnpr.healthbot.swagger.models.rule_schema_i_agent import RuleSchemaIAgent
from jnpr.healthbot.swagger.models.rule_schema_i_agent_args import RuleSchemaIAgentArgs
from jnpr.healthbot.swagger.models.rule_schema_nativegpb import RuleSchemaNativegpb
from jnpr.healthbot.swagger.models.rule_schema_openconfig import RuleSchemaOpenconfig
from jnpr.healthbot.swagger.models.rule_schema_reference import RuleSchemaReference
from jnpr.healthbot.swagger.models.rule_schema_reference_dataifmissing import RuleSchemaReferenceDataifmissing
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties import RuleSchemaRuleproperties
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_catalogue import RuleSchemaRulepropertiesCatalogue
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_helperfiles import RuleSchemaRulepropertiesHelperfiles
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices import RuleSchemaRulepropertiesSupporteddevices
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper import RuleSchemaRulepropertiesSupporteddevicesJuniper
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_operatingsystem import RuleSchemaRulepropertiesSupporteddevicesJuniperOperatingsystem
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_platforms import RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_products import RuleSchemaRulepropertiesSupporteddevicesJuniperProducts
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_releases import RuleSchemaRulepropertiesSupporteddevicesJuniperReleases
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_releases1 import RuleSchemaRulepropertiesSupporteddevicesJuniperReleases1
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_operatingsystems import RuleSchemaRulepropertiesSupporteddevicesOperatingsystems
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_othervendor import RuleSchemaRulepropertiesSupporteddevicesOthervendor
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_platforms import RuleSchemaRulepropertiesSupporteddevicesPlatforms
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_products import RuleSchemaRulepropertiesSupporteddevicesProducts
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_releases import RuleSchemaRulepropertiesSupporteddevicesReleases
from jnpr.healthbot.swagger.models.rule_schema_sensor import RuleSchemaSensor
from jnpr.healthbot.swagger.models.rule_schema_sensor1 import RuleSchemaSensor1
from jnpr.healthbot.swagger.models.rule_schema_sflow import RuleSchemaSflow
from jnpr.healthbot.swagger.models.rule_schema_snmp import RuleSchemaSnmp
from jnpr.healthbot.swagger.models.rule_schema_snmpnotification import RuleSchemaSnmpnotification
from jnpr.healthbot.swagger.models.rule_schema_syslog import RuleSchemaSyslog
from jnpr.healthbot.swagger.models.rule_schema_term import RuleSchemaTerm
from jnpr.healthbot.swagger.models.rule_schema_then import RuleSchemaThen
from jnpr.healthbot.swagger.models.rule_schema_then_argument import RuleSchemaThenArgument
from jnpr.healthbot.swagger.models.rule_schema_then_retry import RuleSchemaThenRetry
from jnpr.healthbot.swagger.models.rule_schema_then_retry_backoff import RuleSchemaThenRetryBackoff
from jnpr.healthbot.swagger.models.rule_schema_then_status import RuleSchemaThenStatus
from jnpr.healthbot.swagger.models.rule_schema_then_userdefinedaction import RuleSchemaThenUserdefinedaction
from jnpr.healthbot.swagger.models.rule_schema_then_workflow import RuleSchemaThenWorkflow
from jnpr.healthbot.swagger.models.rule_schema_trigger import RuleSchemaTrigger
from jnpr.healthbot.swagger.models.rule_schema_variable import RuleSchemaVariable
from jnpr.healthbot.swagger.models.rule_schema_vector import RuleSchemaVector
from jnpr.healthbot.swagger.models.rule_schema_when import RuleSchemaWhen
from jnpr.healthbot.swagger.models.rule_schema_when_doesnotmatchwith import RuleSchemaWhenDoesnotmatchwith
from jnpr.healthbot.swagger.models.rule_schema_when_equalto import RuleSchemaWhenEqualto
from jnpr.healthbot.swagger.models.rule_schema_when_exists import RuleSchemaWhenExists
from jnpr.healthbot.swagger.models.rule_schema_when_increasingatleastbyrate import RuleSchemaWhenIncreasingatleastbyrate
from jnpr.healthbot.swagger.models.rule_schema_when_increasingatleastbyvalue import RuleSchemaWhenIncreasingatleastbyvalue
from jnpr.healthbot.swagger.models.rule_schema_when_maxrateofincrease import RuleSchemaWhenMaxrateofincrease
from jnpr.healthbot.swagger.models.rule_schema_when_range import RuleSchemaWhenRange
from jnpr.healthbot.swagger.models.rule_schema_when_userdefinedfunction import RuleSchemaWhenUserdefinedfunction
from jnpr.healthbot.swagger.models.rule_schema_where import RuleSchemaWhere
from jnpr.healthbot.swagger.models.sample_schema import SampleSchema
from jnpr.healthbot.swagger.models.scheduler_schema import SchedulerSchema
from jnpr.healthbot.swagger.models.scheduler_schema_repeat import SchedulerSchemaRepeat
from jnpr.healthbot.swagger.models.scheduler_schema_repeat_interval import SchedulerSchemaRepeatInterval
from jnpr.healthbot.swagger.models.scheduler_schema_runfor import SchedulerSchemaRunfor
from jnpr.healthbot.swagger.models.schedulers_schema import SchedulersSchema
from jnpr.healthbot.swagger.models.service_status import ServiceStatus
from jnpr.healthbot.swagger.models.sflow_schema import SflowSchema
from jnpr.healthbot.swagger.models.sflow_schema_sflow import SflowSchemaSflow
from jnpr.healthbot.swagger.models.sflow_schema_sflow_counterrecord import SflowSchemaSflowCounterrecord
from jnpr.healthbot.swagger.models.sflow_schema_sflow_field import SflowSchemaSflowField
from jnpr.healthbot.swagger.models.sflow_schema_sflow_protocol import SflowSchemaSflowProtocol
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sample import SflowSchemaSflowSample
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield import SflowSchemaSflowSizebasedonfield
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield_then import SflowSchemaSflowSizebasedonfieldThen
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield_then1 import SflowSchemaSflowSizebasedonfieldThen1
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield_whenequal import SflowSchemaSflowSizebasedonfieldWhenequal
from jnpr.healthbot.swagger.models.site_schema import SiteSchema
from jnpr.healthbot.swagger.models.snmp_notification_schema import SnmpNotificationSchema
from jnpr.healthbot.swagger.models.snmpnotification_schema_snmpnotification import SnmpnotificationSchemaSnmpnotification
from jnpr.healthbot.swagger.models.snmpnotification_schema_snmpnotification_v3 import SnmpnotificationSchemaSnmpnotificationV3
from jnpr.healthbot.swagger.models.snmpnotification_schema_snmpnotification_v3_usm import SnmpnotificationSchemaSnmpnotificationV3Usm
from jnpr.healthbot.swagger.models.snmpv3_usm_user_schema import Snmpv3UsmUserSchema
from jnpr.healthbot.swagger.models.snmpv3_usm_users_schema import Snmpv3UsmUsersSchema
from jnpr.healthbot.swagger.models.snmpv3usmuser_schema_authentication import Snmpv3usmuserSchemaAuthentication
from jnpr.healthbot.swagger.models.snmpv3usmuser_schema_privacy import Snmpv3usmuserSchemaPrivacy
from jnpr.healthbot.swagger.models.ssh_key_profile_schema import SshKeyProfileSchema
from jnpr.healthbot.swagger.models.syslog_schema import SyslogSchema
from jnpr.healthbot.swagger.models.syslog_schema_syslog import SyslogSchemaSyslog
from jnpr.healthbot.swagger.models.system_settings_schema import SystemSettingsSchema
from jnpr.healthbot.swagger.models.table_schema import TableSchema
from jnpr.healthbot.swagger.models.tagging_profile_schema import TaggingProfileSchema
from jnpr.healthbot.swagger.models.tagging_profiles_schema import TaggingProfilesSchema
from jnpr.healthbot.swagger.models.taggingprofile_schema_policy import TaggingprofileSchemaPolicy
from jnpr.healthbot.swagger.models.taggingprofile_schema_term import TaggingprofileSchemaTerm
from jnpr.healthbot.swagger.models.taggingprofile_schema_then import TaggingprofileSchemaThen
from jnpr.healthbot.swagger.models.taggingprofile_schema_then_addfield import TaggingprofileSchemaThenAddfield
from jnpr.healthbot.swagger.models.taggingprofile_schema_then_addkey import TaggingprofileSchemaThenAddkey
from jnpr.healthbot.swagger.models.taggingprofile_schema_when import TaggingprofileSchemaWhen
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_doesnotmatchwith import TaggingprofileSchemaWhenDoesnotmatchwith
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_equalto import TaggingprofileSchemaWhenEqualto
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_exists import TaggingprofileSchemaWhenExists
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_matcheswithscheduler import TaggingprofileSchemaWhenMatcheswithscheduler
from jnpr.healthbot.swagger.models.template_schema import TemplateSchema
from jnpr.healthbot.swagger.models.time_range_mandatory import TimeRangeMandatory
from jnpr.healthbot.swagger.models.tlive_kafka_oc_schema import TliveKafkaOcSchema
from jnpr.healthbot.swagger.models.tlive_kafka_ocs_schema import TliveKafkaOcsSchema
from jnpr.healthbot.swagger.models.tlivekafkaoc_schema_security import TlivekafkaocSchemaSecurity
from jnpr.healthbot.swagger.models.tlivekafkaoc_schema_security_sasl import TlivekafkaocSchemaSecuritySasl
from jnpr.healthbot.swagger.models.token import Token
from jnpr.healthbot.swagger.models.topic_field_capture_schema import TopicFieldCaptureSchema
from jnpr.healthbot.swagger.models.topic_schema import TopicSchema
from jnpr.healthbot.swagger.models.topic_schema_argument import TopicSchemaArgument
from jnpr.healthbot.swagger.models.topic_schema_dependson import TopicSchemaDependson
from jnpr.healthbot.swagger.models.topic_schema_field import TopicSchemaField
from jnpr.healthbot.swagger.models.topic_schema_foreverydevice import TopicSchemaForeverydevice
from jnpr.healthbot.swagger.models.topic_schema_foreverynetworkgroup import TopicSchemaForeverynetworkgroup
from jnpr.healthbot.swagger.models.topic_schema_function import TopicSchemaFunction
from jnpr.healthbot.swagger.models.topic_schema_getdependenciesfromcache import TopicSchemaGetdependenciesfromcache
from jnpr.healthbot.swagger.models.topic_schema_locateresource import TopicSchemaLocateresource
from jnpr.healthbot.swagger.models.topic_schema_resource import TopicSchemaResource
from jnpr.healthbot.swagger.models.topic_schema_source import TopicSchemaSource
from jnpr.healthbot.swagger.models.topic_schema_source_rule import TopicSchemaSourceRule
from jnpr.healthbot.swagger.models.topic_schema_term import TopicSchemaTerm
from jnpr.healthbot.swagger.models.topic_schema_userdefinedfunction import TopicSchemaUserdefinedfunction
from jnpr.healthbot.swagger.models.topic_schema_variable import TopicSchemaVariable
from jnpr.healthbot.swagger.models.topic_schema_where import TopicSchemaWhere
from jnpr.healthbot.swagger.models.topic_schema_where_argument import TopicSchemaWhereArgument
from jnpr.healthbot.swagger.models.topic_schema_where_doesnotmatchwith import TopicSchemaWhereDoesnotmatchwith
from jnpr.healthbot.swagger.models.topic_schema_where_equalto import TopicSchemaWhereEqualto
from jnpr.healthbot.swagger.models.topic_schema_where_eval import TopicSchemaWhereEval
from jnpr.healthbot.swagger.models.topic_schema_where_matcheswith import TopicSchemaWhereMatcheswith
from jnpr.healthbot.swagger.models.topic_schema_where_userdefinedfunction import TopicSchemaWhereUserdefinedfunction
from jnpr.healthbot.swagger.models.topic_schema_withcapturegroup import TopicSchemaWithcapturegroup
from jnpr.healthbot.swagger.models.topics_schema import TopicsSchema
from jnpr.healthbot.swagger.models.trigger_action_schema import TriggerActionSchema
from jnpr.healthbot.swagger.models.trigger_schema import TriggerSchema
from jnpr.healthbot.swagger.models.trigger_schema_triggers import TriggerSchemaTriggers
from jnpr.healthbot.swagger.models.tsdb_error import TsdbError
from jnpr.healthbot.swagger.models.tsdb_error_results import TsdbErrorResults
from jnpr.healthbot.swagger.models.tsdb_post_body import TsdbPostBody
from jnpr.healthbot.swagger.models.tsdb_post_body_items import TsdbPostBodyItems
from jnpr.healthbot.swagger.models.tsdb_post_body_items_device_aggregation import TsdbPostBodyItemsDeviceAggregation
from jnpr.healthbot.swagger.models.tsdb_post_body_items_outer_queries import TsdbPostBodyItemsOuterQueries
from jnpr.healthbot.swagger.models.tsdb_results import TsdbResults
from jnpr.healthbot.swagger.models.tsdb_results_results import TsdbResultsResults
from jnpr.healthbot.swagger.models.tsdb_results_series import TsdbResultsSeries
from jnpr.healthbot.swagger.models.tsdb_schema import TsdbSchema
from jnpr.healthbot.swagger.models.user_schema import UserSchema
from jnpr.healthbot.swagger.models.user_schema_groups import UserSchemaGroups
from jnpr.healthbot.swagger.models.uuid_object import UuidObject
from jnpr.healthbot.swagger.models.when_lhs_rhs_group import WhenLhsRhsGroup
from jnpr.healthbot.swagger.models.workflow_argument_group_schema import WorkflowArgumentGroupSchema
from jnpr.healthbot.swagger.models.workflow_argument_group_schema_inner import WorkflowArgumentGroupSchemaInner
from jnpr.healthbot.swagger.models.workflow_command_schema import WorkflowCommandSchema
from jnpr.healthbot.swagger.models.workflow_command_schema_commands import WorkflowCommandSchemaCommands
from jnpr.healthbot.swagger.models.workflow_cron_options_schema import WorkflowCronOptionsSchema
from jnpr.healthbot.swagger.models.workflow_instance_schema import WorkflowInstanceSchema
from jnpr.healthbot.swagger.models.workflow_instance_schema_parameters import WorkflowInstanceSchemaParameters
from jnpr.healthbot.swagger.models.workflow_instances_schema import WorkflowInstancesSchema
from jnpr.healthbot.swagger.models.workflow_notification_schema import WorkflowNotificationSchema
from jnpr.healthbot.swagger.models.workflow_schema import WorkflowSchema
from jnpr.healthbot.swagger.models.workflow_schema_artifact import WorkflowSchemaArtifact
from jnpr.healthbot.swagger.models.workflow_schema_dataxml import WorkflowSchemaDataxml
from jnpr.healthbot.swagger.models.workflow_schema_grok import WorkflowSchemaGrok
from jnpr.healthbot.swagger.models.workflow_schema_input import WorkflowSchemaInput
from jnpr.healthbot.swagger.models.workflow_schema_json import WorkflowSchemaJson
from jnpr.healthbot.swagger.models.workflow_schema_output import WorkflowSchemaOutput
from jnpr.healthbot.swagger.models.workflow_schema_regex import WorkflowSchemaRegex
from jnpr.healthbot.swagger.models.workflow_schema_step import WorkflowSchemaStep
from jnpr.healthbot.swagger.models.workflow_schema_suspend import WorkflowSchemaSuspend
from jnpr.healthbot.swagger.models.workflow_schema_task import WorkflowSchemaTask
from jnpr.healthbot.swagger.models.workflow_schema_task1 import WorkflowSchemaTask1
from jnpr.healthbot.swagger.models.workflow_schema_workflow import WorkflowSchemaWorkflow
from jnpr.healthbot.swagger.models.workflow_statistics_schema import WorkflowStatisticsSchema
from jnpr.healthbot.swagger.models.workflows_schema import WorkflowsSchema
