# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SchedulerSchemaRepeat(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'every': 'str',
        'interval': 'SchedulerSchemaRepeatInterval',
        'never': 'list[object]'
    }

    attribute_map = {
        'every': 'every',
        'interval': 'interval',
        'never': 'never'
    }

    def __init__(self, every=None, interval=None, never=None):  # noqa: E501
        """SchedulerSchemaRepeat - a model defined in Swagger"""  # noqa: E501

        self._every = None
        self._interval = None
        self._never = None
        self.discriminator = None

        if every is not None:
            self.every = every
        if interval is not None:
            self.interval = interval
        if never is not None:
            self.never = never

    @property
    def every(self):
        """Gets the every of this SchedulerSchemaRepeat.  # noqa: E501

        Repeat every  # noqa: E501

        :return: The every of this SchedulerSchemaRepeat.  # noqa: E501
        :rtype: str
        """
        return self._every

    @every.setter
    def every(self, every):
        """Sets the every of this SchedulerSchemaRepeat.

        Repeat every  # noqa: E501

        :param every: The every of this SchedulerSchemaRepeat.  # noqa: E501
        :type: str
        """
        allowed_values = ["week", "day", "month", "year"]  # noqa: E501
        if every not in allowed_values:
            raise ValueError(
                "Invalid value for `every` ({0}), must be one of {1}"  # noqa: E501
                .format(every, allowed_values)
            )

        self._every = every

    @property
    def interval(self):
        """Gets the interval of this SchedulerSchemaRepeat.  # noqa: E501


        :return: The interval of this SchedulerSchemaRepeat.  # noqa: E501
        :rtype: SchedulerSchemaRepeatInterval
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this SchedulerSchemaRepeat.


        :param interval: The interval of this SchedulerSchemaRepeat.  # noqa: E501
        :type: SchedulerSchemaRepeatInterval
        """

        self._interval = interval

    @property
    def never(self):
        """Gets the never of this SchedulerSchemaRepeat.  # noqa: E501

        Never repeat scheduling  # noqa: E501

        :return: The never of this SchedulerSchemaRepeat.  # noqa: E501
        :rtype: list[object]
        """
        return self._never

    @never.setter
    def never(self, never):
        """Sets the never of this SchedulerSchemaRepeat.

        Never repeat scheduling  # noqa: E501

        :param never: The never of this SchedulerSchemaRepeat.  # noqa: E501
        :type: list[object]
        """

        self._never = never

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SchedulerSchemaRepeat, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchedulerSchemaRepeat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
